@@ -15,7 +15,6 @@
 #
 import os
 import sys
-import dctap
 
 sys.path.insert(0, os.path.abspath("../dctap/"))
 
@@ -26,7 +25,8 @@ project = "dctap-python"
 copyright = "2021, DCMI"
 
 # The full version, including alpha/beta/rc tags
-release = dctap.__version__
+# See ../dctap/__init__.py
+release = "0.3.1"
 
 # -- General configuration ---------------------------------------------------
 
